Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Data ¶
Data returns the contents of a file at the given path.
func DataAs ¶
DataAs interprets the YAML contents of the file at the given path as the given type.
func PrettyJSON ¶
PrettyJSON pretty-prints a struct to a string.
Types ¶
type Wait ¶
Wait extends WaitGroup with a few useful methods to avoid tests having a failure mode of hanging.
func (*Wait) WaitUntil ¶
WaitUntil waits until Done() has been called or the specified duration has elapsed. If Done() is called, then onSuccess is called. If the duration elapses without Done() being called, then onTimeout is called.
Source Files
¶
- data.go
- json.go
- wait.go
- yaml.go
Click to show internal directories.
Click to hide internal directories.